@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2005  Gaspar Sinai <gsinai@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -31,6 +28,7 @@
 #include "swidget/SListBox.h"
 #include "swidget/STextEdit.h"
 #include "swidget/STextDialog.h"
+#include "swindow/SImage.h"
 #include <stoolkit/SIO.h> 
 
 class SFileDialog : public SFrame, 
@@ -49,6 +47,8 @@ public:
   virtual void setForeground (const SColor& fg);
   virtual void setTitleForeground (const SColor& fg);
   virtual void setSliderBackground (const SColor& bg);
+  virtual void setApplicationImage (const SImage& image);
+
   void setLabelForeground (const SColor& fg);
 
   void setFileName (const SString& filename);
@@ -56,6 +56,7 @@ public:
   void setFileTypes (const SStringVector& fileTypes);
   const SStringVector& getFileTypes() const;
 
+
   SString getFileName ();
   SString getUnixFileName ();
   SString getFileType ();
