@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2005  Gaspar Sinai <gsinai@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -25,6 +22,7 @@
 
 #include "swindow/SCanvas.h"
 #include "swindow/SAccelerator.h"
+#include "swindow/SImage.h"
 
 #include "stoolkit/SExcept.h"
 #include "stoolkit/SString.h"
@@ -60,6 +58,7 @@ public:
        unsigned int width, unsigned int height);
   virtual void move (int x, int y);
   virtual SS_Matrix2D  getCurrentMatrix() const;
+  virtual void setApplicationImage (const SImage& im);
 
   /*---------------- from canvas --------------*/
   virtual bool newpath (double x, double y, const SString& id);
