@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2005  Gaspar Sinai <gsinai@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -312,11 +309,11 @@ main (int argc, char *argv[])
 static void
 usage ()
 {
-  fprintf (stderr, version, SD_YUDIT_VERSION);
-  fprintf (stderr,   "usage: uniprint [-out file] [-printer name] [-in file] [-decode name] \n");
-  fprintf (stderr,   "       [-break] [-right|-left] [-hsize header-font-size] [-size font-size\n");
-  fprintf (stderr,   "       [-wrap] [-font truetype.ttf [-font otherfont.ttf [...]] \n\n");
-  fprintf (stderr,   "uniconv [-us] ... will use uniscribe-clone rendering.");
-  fprintf (stderr,   "uniconv -h will get list of suppoerted encodings.   \n");
+  fprintf (stdout, version, SD_YUDIT_VERSION);
+  fprintf (stdout,   "usage: uniprint [-out file] [-printer name] [-in file] [-decode name] \n");
+  fprintf (stdout,   "       [-break] [-right|-left] [-hsize header-font-size] [-size font-size\n");
+  fprintf (stdout,   "       [-wrap] [-font truetype.ttf [-font otherfont.ttf [...]] \n\n");
+  fprintf (stdout,   "uniconv [-us] ... will use uniscribe-clone rendering.");
+  fprintf (stdout,   "uniconv -h will get list of suppoerted encodings.   \n");
 }
 
